@@ -1,15 +1,44 @@
-from numpy import arange, concatenate, array
-from pandas import ExcelFile, read_excel, DataFrame, concat
+from numpy import arange, array, concatenate
+from pandas import concat, DataFrame, ExcelFile, read_excel
 from re import compile, IGNORECASE
 from simpler.terminal import cprint
-from typing import Union, Any, Generator, List, Optional
+from typing import Any, Generator, List, Optional, Union
+
+def simpler_converter():
+	from mysql.connector.constants import FieldFlag
+	from mysql.connector.conversion import MySQLConverter
+
+	class Res(MySQLConverter):
+		def row_to_python(self, row, fields):
+			res = super().row_to_python(row, fields)
+			return res
+
+		def _STRING_to_python(self, value, dsc=None):
+			res = super(Res, self)._STRING_to_python(value, dsc)
+			if dsc[7] & FieldFlag.BINARY:
+				return res.decode(self.charset)
+			return res
+		_VAR_STRING_to_python = _STRING_to_python
+
+		def _DECIMAL_to_python(self, value, desc=None):
+			return float(value.decode(self.charset))
+		_NEWDECIMAL_to_python = _DECIMAL_to_python
+		
+		def _BLOB_to_python(self, value, dsc=None):
+			"""Convert BLOB data type to Python"""
+			return self._STRING_to_python(value, dsc)
+		_LONG_BLOB_to_python = _BLOB_to_python
+		_MEDIUM_BLOB_to_python = _BLOB_to_python
+		_TINY_BLOB_to_python = _BLOB_to_python
+	
+	return Res
 
 class MySQL:
-	''' Connector for the MySQLdb backend with a handful of helpers. '''
+	''' Connector for a mysql backend with a handful of helpers. '''
 	def __init__(
-		self, host: str, user: str, password: str = None, db: str = None,
-		charset: str = 'utf8mb4', use_unicode: bool = True, autocommit: bool = True,
-		max_insertions: int = None, print_queries: bool = False
+		self, host: str = 'localhost', user: str = 'root', password: str = None, db: str = None,
+		charset: str = 'utf8mb4', use_unicode: bool = True, max_insertions: int = None,
+		print_queries: bool = False, native_types: bool = True
 	) -> None:
 		self.max_insertions, self._cursor = max_insertions, None
 		self._connection = {
@@ -17,8 +46,9 @@ class MySQL:
 			'user': user,
 			'charset': charset,
 			'use_unicode': use_unicode,
-			'autocommit': autocommit
 		}
+		if native_types:
+			self._connection['converter_class'] = simpler_converter()
 		if password:
 			self._connection.update({'passwd': password, 'auth_plugin': 'mysql_native_password'})
 		if db:
@@ -40,21 +70,27 @@ class MySQL:
 		if self._cursor is None:
 			from mysql.connector import connect
 			self._connection = connect(**self._connection)
-			self._cursor = self._connection.cursor()
+			self._cursor = self._connection.cursor(buffered=True)
 		return self._cursor
 
-	def execute(self, query: str, params: tuple = None):
-		''' Wrapper for the MySQLdb execute method that won't send the params argument
+	def execute(self, query: str, params: tuple = None, multi: bool = False):
+		''' Wrapper for the mysql.connector execute method that won't send the params argument
 		if the params are empty, thus avoiding the need to replace % with %%. '''
 		if self.print_queries:
 			self.print_query(query, params)
-		return self.cursor().execute(query, params if params is not None and len(params) else None)
+		statement = self.cursor().execute(query, params if params is not None and len(params) else None, multi)
+		if multi:
+			try:
+				list(statement)
+			except RuntimeError:  # see https://bugs.mysql.com/bug.php?id=87818
+				pass
+		self._connection.commit()
 
 	def print_query(self, query: str, params: tuple = None, color: str = 'yellow', max_size: int = 1000):
 		if len(query) > max_size:
 			query = query[:max_size // 2] + '...' + query[-max_size // 2:]
 		try:
-			formatted = query.strip() % params
+			formatted = query.strip() % params if params is not None and len(params) else query.strip()
 		except:
 			formatted = query.strip()
 		cprint(formatted + ';', fg='yellow')
@@ -189,12 +225,10 @@ class MySQL:
 		the data `is_literal=True`, which will wrap strings with quotes for its insertion. '''
 		if value is None:
 			value = 'NULL'
-		elif type(value) == str:
-			value = self._connection.escape_string(value).decode()
+		else:
+			value = self._connection.converter.escape(str(value))
 			if is_literal:
 				value = '"%s"' % value
-		else:
-			value = self._connection.string_literal(value).decode()
 		return value
 
 class Excel:
